ClockController class
A controller for the ClockWidget when in timer or stopwatch mode.
Constructors
- ClockController()
- Creates a new ClockController.
Properties
-
currentDuration
→ ValueNotifier<
Duration> -
A ValueNotifier that holds the current duration of the timer or stopwatch.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isRunning
→ ValueNotifier<
bool> -
A ValueNotifier that indicates whether the timer or stopwatch is running.
final
- onPause ↔ VoidCallback?
-
A callback function to pause the timer or stopwatch.
getter/setter pair
- onReset ↔ VoidCallback?
-
A callback function to reset the timer or stopwatch.
getter/setter pair
- onStart ↔ VoidCallback?
-
A callback function to start the timer or stopwatch.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited